classdef DataReader
    % TODO: create a super class, the static methods should be transformed
    
    % EColiFBFPReader
    %   static methods for reading the results of the simulation
    
    methods (Access = public, Static)
        
        function handle = displayExpData(process, extended)
            configuration = Configurations();
            
            if process == "EcoliFB"
                expDataFile = configuration.ECOLI_DATA_FULL_PATH;
                expData = EColiFBFPReader.loadExperimentalData(expDataFile);
                
                Texp = expData(:, 1);
                Xexp = expData(:, 4);
                Sexp = expData(:, 5);
                
                if ~extended
                    handle = EColiFBFPPlot.displayExpData(Texp, Xexp, Sexp);
                else
                    % add o2
                    tdo1 = expData(:, 6);
                    nanIndiced = find(isnan(tdo1));
                    
                    indexOfLastValue = nanIndiced(1) - 1;
                    tdo1 = tdo1(1: indexOfLastValue);
                    
                    DOd = expData(:, 7);
                    DOd = DOd(1: indexOfLastValue);
                    
                    DOexp = interp1(tdo1, DOd, Texp);
                    
                    handle = EColiFBFPExtendedPlot.displayExpData(Texp, Xexp, Sexp, DOexp);
                end
            else
                % Gluconic Acid
                expDataFile = configuration.GLUCONIC_ACID_DATA_FULL_PATH;
                expData = GluconicAcidBFPReader.loadExperimentalData(expDataFile);
                
                Texp    = expData(:, 1);
                Xexp    = expData(:, 2);
                Sexp    = expData(:, 3); 
                GAexp   = expData(:, 4);
                O2exp   = expData(:, 5);
                
                [handleXS, handleGAO2] = GABFPPlot.displayExpData(Texp, Xexp, Sexp, GAexp, O2exp);
                handle =  [handleXS, handleGAO2];
            end
        end
        
        function displayModelData(process, extended, filePath, handle, legend, colorIndex)
                   
            if process == "EcoliFB"
                data = xlsread(filePath, 'A:D');
                modData = data(7:end, :);  

                Tmod = modData(:, 1);
                Xmod = modData(:, 2);
                Smod = modData(:, 3);                 
                
                if ~extended
                    EColiFBFPPlot.displayModelData(Tmod, Xmod, Smod, legend, handle, colorIndex);
                    hold on;
                else
                    DOmod = modData(:, 4);
                    EColiFBFPExtendedPlot.displayModelData(Tmod, Xmod, Smod, DOmod, legend, handle, colorIndex);
                    hold on;
                end
            else
                % Gluconic acid
                data = xlsread(filePath, 'A:E');
                modData = data(7:end, :);  

                Tmod    = modData(:, 1);
                Xmod    = modData(:, 2);
                Smod    = modData(:, 3); 
                GAmod   = modData(:, 4);
                O2mod   = modData(:, 5);
                
                handleXS = handle(1);
                handleGAO2 = handle(2);
                GABFPPlot.displayModelData(Tmod, Xmod, Smod, GAmod, O2mod, legend, handleXS, handleGAO2, colorIndex)
                hold on;
            end
        end
    end
end