classdef EColiFBFPExtendedPlot
    % EColiFBFPExtendedPlot
    %   static methods for plotting the results of the simulation
    
    properties (Access = private, Constant)
    end
    
    methods (Access = public, Static)
        %% graphical comparison between the experimental and model data
        function handle = displayExpData(Texp, Xexp, Sexp, DOexp)
            handle = figure;
              
            axes('FontSize', 14);

            subplot(3, 1, 1);
              
            % Biomass
            plot(Texp, Xexp, 'k', 'LineWidth', 1, 'DisplayName', 'Experimental data'), hold on
                            
            xlabel('Time, [h]');
            ylabel('Biomass, [g.L^{-1}]');
            legend show
            legend('Location','northwest');
                       
            grid on;
            
            subplot(3, 1, 2);
            
            % Substrate
            plot(Texp, Sexp, 'k', 'LineWidth', 1, 'DisplayName', 'Experimental data'), hold on
            
            xlabel('Time, [h]');
            ylabel('Substrate, [g.L^{-1}]');      
            legend show
            
            axis([6 12 0 1.5]);
            grid on;
            
            subplot(3, 1, 3);
                
            % Dissolved oxygen
            plot(Texp, DOexp, 'k', 'LineWidth', 1, 'DisplayName', 'Experimental data'), hold on
            
            xlabel('Time, [h]');
            ylabel('Dissolved oxygen, [%]');      
            legend show

            grid on;
        end
        
        function handle = displayModelData(Tmod, Xmod, Smod, DOmod, algName, handle, index)
            figure(handle);
            
            C = {'r', 'b', 'g', 'c', 'm', [.5 .6 .7], [.8 .2 .6]};
              
            axes('FontSize', 14);
           
            subplot(3, 1, 1);
                                 
            plot(Tmod, Xmod, 'color', C{index}, 'LineWidth', 1, 'DisplayName', algName), hold on
                            
            xlabel('Time, [h]');
            ylabel('Biomass, [g.L^{-1}]');
            legend show;
            legend('Location','northwest');                     
            
            grid on;
            drawnow update
            
            subplot(3, 1, 2);
                        
            plot(Tmod, Smod, 'color', C{index}, 'LineWidth', 1, 'DisplayName', algName), hold on
            
            xlabel('Time, [h]');
            ylabel('Substrate, [g.L^{-1}]');      
            legend show
            
            axis([6 12 0 1.5]);
            grid on;
            drawnow update
            
            subplot(3, 1, 3);
                
            % Dissolved oxygen
            plot(Tmod, DOmod, 'color', C{index}, 'LineWidth', 1, 'DisplayName', algName), hold on
            
            xlabel('Time, [h]');
            ylabel('Dissolved oxygen, [%]');      
            legend show

            grid on;
            drawnow update
        end
        
    end
    
end

