classdef GABFPPlot
    % GABFPPlot
    %   static methods for plotting the results of the simulation
    
    properties (Access = private, Constant)
    end
    
    % Too much code duplication!
    
    methods (Access = public, Static)
        %% display experimental data
        function [handleXS, handleGAO2] = displayExpData(Texp, Xexp, Sexp, GAexp, O2exp)
            handleXS = figure;
              
            axes('FontSize', 14);

            subplot(2, 1, 1);
                                 
            plot(Texp, Xexp, 'k*', 'LineWidth', 1, 'DisplayName', 'Experimental data'), hold on
                            
            xlabel('Time, [h]');
            ylabel('Biomass, [g.L^{-1}]');
            legend show
            legend('Location','northwest');
                       
            grid on;
            
            subplot(2, 1, 2);
                        
            plot(Texp, Sexp, 'k*', 'LineWidth', 1, 'DisplayName', 'Experimental data'), hold on
            
            xlabel('Time, [h]');
            ylabel('Substrate, [g.L^{-1}]');      
            legend show
            
%             axis([6 12 0 1.5]);
            grid on;
            
            handleGAO2 = figure;
              
            axes('FontSize', 14);

            subplot(2, 1, 1);
                                 
            plot(Texp, GAexp, 'k*', 'LineWidth', 1, 'DisplayName', 'Experimental data'), hold on
                            
            xlabel('Time, [h]');
            ylabel('Gluconic acid, [g.L^{-1}]');
            legend show
            legend('Location','northwest');
                       
            grid on;
            
            subplot(2, 1, 2);
                        
            plot(Texp, O2exp, 'k*', 'LineWidth', 1, 'DisplayName', 'Experimental data'), hold on
            
            xlabel('Time, [h]');
            ylabel('Dissolved oxygen, [g.L^{-1}]');      
            legend show
            
            axis([0 30 0 7]);
            grid on;
        end
        
        %% display model data on the same figure
        function [handleXS, handleGAO2] = displayModelData(Tmod, Xmod, Smod, GAmod, O2mod, algName, handleXS, handleGAO2, index)
                        
            C = {'r', 'b', 'g', 'c', 'm', [.5 .6 .7], [.8 .2 .6]};
            
            figure(handleXS);
            axes('FontSize', 14);
           
            subplot(2, 1, 1);
                                 
            plot(Tmod, Xmod, 'color', C{index}, 'LineWidth', 1, 'DisplayName', algName), hold on
                            
            xlabel('Time, [h]');
            ylabel('Biomass, [g.L^{-1}]');
            legend show;
            legend('Location','northwest');                     
            
            grid on;
            drawnow update
            
            subplot(2, 1, 2);
                        
            plot(Tmod, Smod, 'color', C{index}, 'LineWidth', 1, 'DisplayName', algName), hold on
            
            xlabel('Time, [h]');
            ylabel('Substrate, [g.L^{-1}]');      
            legend show
            
%             axis([6 12 0 1.5]);
            grid on;
            drawnow update
            
            figure(handleGAO2);
            axes('FontSize', 14);
           
            subplot(2, 1, 1);
                                 
            plot(Tmod, GAmod, 'color', C{index}, 'LineWidth', 1, 'DisplayName', algName), hold on
                            
            xlabel('Time, [h]');
            ylabel('Gluconic acid, [g.L^{-1}]');
            legend show;
            legend('Location','northwest');                     
            
            grid on;
            drawnow update
            
            subplot(2, 1, 2);
                        
            plot(Tmod, O2mod, 'color', C{index}, 'LineWidth', 1, 'DisplayName', algName), hold on
            
            xlabel('Time, [h]');
            ylabel('Dissolved oxygen, [g.L^{-1}]');      
            legend show
            
            axis([0 30 0 7]);
            grid on;
            drawnow update
        end
        
        %% graphical comparison between the experimental and model data
        function displayData(Tmod, Xmod, Smod, GAmod, O2mod, Texp, Xexp, Sexp, GAexp, O2exp)
           GABFPPlot.displayDataOnNamedPlot(Tmod, Xmod, Smod, GAmod, O2mod, Texp, Xexp, Sexp, GAexp, O2exp, "");
            
%             figure (1);
%             axes('FontSize', 14);
%            
%             subplot(2, 1, 1);
%                        
%             xlabel('Time, [h]');
%             ylabel('Biomass, [g.L^{-1}]');
%             
%             plot(Texp, Xexp, 'r', 'LineWidth', 1), grid on, hold on
%             plot(Tmod, Xmod, 'b', 'LineWidth', 1), grid on, hold on
%             
%             legend('Experimental data', 'Model', 'Location', 'northwest'); 
%             drawnow update;
%             
%             subplot(2, 1, 2);
%                       
%             xlabel('Time, [h]');
%             ylabel('Substrate, [g.L^{-1}]');
%             
%             plot(Texp, Sexp, 'r', 'LineWidth', 1), grid on, hold on
%             plot(Tmod, Smod, 'b', 'LineWidth', 1), grid on, hold on
%             
%             legend('Experimental data', 'Model');
%             drawnow update;
%             
%             figure (2)
%             axes('FontSize', 14);
%            
%             subplot(2, 1, 1);
%             
%             xlabel('Time, [h]');
%             ylabel('Gluconic acid, [g.L^{-1}]');
%             
%             plot(Texp, GAexp, 'r', 'LineWidth', 1), grid on, hold on
%             plot(Tmod, GAmod, 'b', 'LineWidth', 1), grid on, hold on
%             
%             legend('Experimental data', 'Model', 'Location', 'northwest'); 
%             drawnow update;
%             
%             subplot(2, 1, 2);
%             
%             xlabel('Time, [h]');
%             ylabel('Dissolved oxygen, [g.L^{-1}]');
%             
%             plot(Texp, O2exp, 'r', 'LineWidth', 1), grid on, hold on
%             plot(Tmod, O2mod, 'b', 'LineWidth', 1), grid on, hold on
%             
%             legend('Experimental data', 'Model'); 
%             drawnow update;
            
        end
        
        %% graphical comparison between the experimental and model data
        % for the best estimates of the problem parameters
        function displayDataOnNamedPlot(Tmod, Xmod, Smod, GAmod, O2mod, Texp, Xexp, Sexp, GAexp, O2exp, name)
            
            if name == ""
                figure (1); 
            else
                handle = figure();
                handle.Name = name;
            end
             
            axes('FontSize', 14);
           
            subplot(2, 1, 1);
                        
            plot(Texp, Xexp, 'r*', 'LineWidth', 1), hold on
            plot(Tmod, Xmod, 'b', 'LineWidth', 1), hold on
            
            xlabel('Time, [h]');
            ylabel('Biomass, [g.L^{-1}]');
            
            legend('Experimental data', 'Model', 'Location', 'northwest'); 
            if name ~= ""
                title(name);
            end
            
            grid on;
            drawnow update;
            
            subplot(2, 1, 2);
                                 
            plot(Texp, Sexp, 'r*', 'LineWidth', 1), hold on
            plot(Tmod, Smod, 'b', 'LineWidth', 1), hold on
            
            xlabel('Time, [h]');
            ylabel('Substrate, [g.L^{-1}]');
            
            legend('Experimental data', 'Model');
            grid on;
            drawnow update;
            
            if name == ""
                figure (2);
            else
                handle = figure();
                handle.Name = name;
            end
            
            axes('FontSize', 14);
           
            subplot(2, 1, 1);
                       
            plot(Texp, GAexp, 'r*', 'LineWidth', 1), hold on
            plot(Tmod, GAmod, 'b', 'LineWidth', 1), hold on
            
            xlabel('Time, [h]');
            ylabel('Gluconic acid, [g.L^{-1}]');
            
            legend('Experimental data', 'Model', 'Location', 'northwest'); 
            if name ~= ""
                title(name);
            end
            
            grid on;
            drawnow update;
            
            
            subplot(2, 1, 2);
            
            plot(Texp, O2exp, 'r*', 'LineWidth', 1), hold on
            plot(Tmod, O2mod, 'b', 'LineWidth', 1), hold on
                       
            xlabel('Time, [h]');
            ylabel('Dissolved oxygen, [g.L^{-1}]');
            
            axis([0 30 0 7]);
            
            legend('Experimental data', 'Model');
            grid on;
            drawnow update;
            
        end  
    end
        
    methods (Access = private, Static)
        
    end
    
end

