classdef ProcessModelFactory
    % ProcessModelFactory creates an object of a specific ProcessModel subclass
    %   the subclass is determined by the selected equations and the
    %   kinetics
    
    methods (Access = public, Static = true)
        function processModel = createProcessModel(fermentationProcessName, selectedEquationsList, selectedKinetics)
            configuration = Configurations();
            
            if fermentationProcessName ~= "EcoliFB" && fermentationProcessName ~= "GAB"
                exception = MException('ProcessType:Unsupported', 'Unsupported type of process!');
                throw(exception);
            end
            
            % EColi FB cultivation process is selected
            
            modelKinetics = "";
            
            if fermentationProcessName == "EcoliFB"
                if selectedKinetics == "Monod"
                    modelKinetics = configuration.BASIC_ECOLI_FB_FP_MONOD;
                elseif selectedKinetics == "Contoa"
                    modelKinetics = configuration.BASIC_ECOLI_FB_FP_CONTOA;
                elseif selectedKinetics == "Fujimoto"
                    modelKinetics = configuration.BASIC_ECOLI_FB_FP_FUJIMOTO;
                else
                    exception = MException('Kinetics:Unsupported', 'Unsupported kinetics!');
                    throw(exception);
                end
            end
            
            
            % TODO: Kinetics for the extended model...
            % only Monod is supported for now..
            listOfAdditionalEquations = ProcessModel.findAdditionalEquations(selectedEquationsList.elements);
            
            numberOfAdditionalEquations = length(listOfAdditionalEquations);
     
            if numberOfAdditionalEquations == 0
                % NOTE: use the name only, DO NOT add the extension .slx for
                % the model names
                if fermentationProcessName == "EcoliFB"
                    processModel = ...
                        EColiFBFPModel(modelKinetics, configuration.ECOLI_MODELS_PATH, ...
                                  selectedEquationsList, selectedKinetics, ...
                                  configuration.ECOLI_DATA_FULL_PATH);
                elseif fermentationProcessName == "GAB"
                    processModel= ...
                        GABFPModel(configuration.BASIC_GAB_FP_MONOD, ...
                                       configuration.GAB_MODELS_PATH, ...
                                       selectedEquationsList, selectedKinetics, ...
                                       configuration.GLUCONIC_ACID_DATA_FULL_PATH);
                end
            else
                processModel = ...
                    EColiFBFPExtendedModel(configuration.EXTENDED_ECOLI_FB_FP_MONOD, ...
                                           configuration.ECOLI_MODELS_PATH, ...
                                           selectedEquationsList, selectedKinetics, ...
                                           configuration.ECOLI_DATA_FULL_PATH);
            end
        end
    end
    
end

