classdef EAGA < GeneticAlgorithm
    %   Properties:
    %       
    
    properties
        
    end
       
    methods (Access = public)
         %% constructor
         function this = EAGA(description, problem)
            if nargin ~= 2
                exception = MException('InputParameters:WrongNumber', 'Wrong number of input parameters!');
                throw(exception);           
            end
            
            this = this@GeneticAlgorithm(description, problem);
            % First 6 parameters should be GA parameters!
         end
         
        %% overriding the abstract methods
        function [this, solutions, evaluations] = generateInitialPopulation(this)
                       
            numberOfEAParameters = EvolutionaryAlgorithm.getNumberOfParameters();
            
            % extract the last numberOfEAParameters values for the list
            filtertedParametersList = this.description.parametersList(end - numberOfEAParameters + 1: end);
            
            eaDescription = this.description;
            eaDescription.parametersList = filtertedParametersList;
                                
            ea = EvolutionaryAlgorithm(eaDescription, this.problem);
            
            numberOfVariables = this.problem.model.nvar;
            solutions = zeros(this.nind, numberOfVariables);
            
            % evaluations for the initial population
            evaluations = zeros(this.nind, 1);
            
            % generate certain number of indivituals in the population
            currentNIND = 0;
            necessaryNIND = this.nind;
            
            while 0 < necessaryNIND
                result = ea.executeModel();
                
                uniqueSolutions = unique(result(:, [1 3:end]), 'rows', 'sorted');
                count = size(uniqueSolutions, 1);
                
                if count < necessaryNIND
                    % insert all unique solutions, 
                    solutions(currentNIND + 1: currentNIND + count, :) = uniqueSolutions(:, 2: end);
                    evaluations(currentNIND + 1: currentNIND + count) = uniqueSolutions(:, 1);
                    
                    currentNIND = currentNIND + count;
                else
                    % the solutions in unique are sorted in ascending
                    % order by the error, extract the first nind 
                    
                    solutions(currentNIND + 1: currentNIND + necessaryNIND, :) = uniqueSolutions(1: necessaryNIND, 2: end);
                    evaluations(currentNIND + 1: currentNIND + necessaryNIND) = uniqueSolutions(1: necessaryNIND, 1);
                    
                    currentNIND = currentNIND + necessaryNIND;
                end
                
                necessaryNIND = this.nind - currentNIND;

%                 bestSolution = result(end, 3: end);
%                 
%                 solutions(i, :) = bestSolution;
%                 evaluations(i) = result(end, 2);
            end
        end
    end
    
end

