classdef OptimizationAlgorithmFactory
    % OptimizationAlgorithmFactory creates an object of a specific OptimizationAlgorithm subclass
    %   the subclass is determined by the selected algorithm description
    
    methods (Access = public, Static = true)
        % static method to create an object of a specific subclass
        % input argument: the description of the optimization algoritm
        % (AlgorithmDescription object)
        function algorithm = createOptimizationAlgorithm(description, problem)
            
            if description.name == "Genetic Algorithm"
                algorithm = GeneticAlgorithm(description, problem);
            elseif description.name == "Evolutionary Algorithm"
                algorithm = EvolutionaryAlgorithm(description, problem);
            elseif description.name == "EA-GA Hybrid"
                algorithm = EAGA(description, problem);
            else
                exception = MException('OptimizationAlgorithm:Unsupported', 'Unsupported optimization algorithm!');
                throw(exception);
            end
            
        end
    end
    
end

