classdef System
    % System 
    %   listOfFermetationProcesses (an array of FermentationProcessDescription objects)
    
    properties
        listOfFermetationProcesses = FermentationProcessDescription.empty;
        listOfOptimizationAlgorithms = AlgorithmDescription.empty;
    end
    
    methods
        %% Constructor of the class
        function this = System()
            
            % initialize the list of fermentation processes
            this = this.initializeListOfFermentationProcesses();
                     
            % initialize the list of optimization algorithms
            this = this.initializeListOfOptimizationProcess();
        end
       
        %% get list of the fermentation processes' descriptions
        function listOfDescriptions = getListOfFPDescriptions(this)
            
            numberOfFermentationProcesses = length(this.listOfFermetationProcesses);
            listOfDescriptions = strings(numberOfFermentationProcesses, 1);
            
            for index = 1 : numberOfFermentationProcesses
                listOfDescriptions(index) = this.listOfFermetationProcesses(index).description;
            end
            
            listOfDescriptions = cellstr(listOfDescriptions);
        end
        
        %% get list of optimization algorithms' descriptions
        function listOfDescriptions = getListOfOptimizationAlgorithmDescriptions(this)
            
            numberOfOtimizationAlgorithms = length(this.listOfOptimizationAlgorithms);
            listOfDescriptions = strings(numberOfOtimizationAlgorithms, 1);
            
            for index = 1 : numberOfOtimizationAlgorithms
                listOfDescriptions(index) = this.listOfOptimizationAlgorithms(index).name;
            end
            
            listOfDescriptions = cellstr(listOfDescriptions); 
        end
    end
    
    methods (Access = private)
        function this = initializeListOfFermentationProcesses(this)
            
            emptyFP = FermentationProcessDescription("", "Empty", " -- Select a fermentation process -- ");
            
%             yeast = FermentationProcessDescription.createYeastFermentationProcess();
            ecoliFB = FermentationProcessDescription.createEColiFermentationProcess();
            glucoicAcid = FermentationProcessDescription.createGlucoicAcidFermentationProcess();
            
%             fpImmobilizedCells = FermentationProcessDescription("FPImmC", "FPImmC", "Fermentation process WITH immobilized cells");
%             fpWithoutImmobilizedCells = FermentationProcessDescription("FPNoImmC", "FPNoImmC", "Fermentation process WITHOUT immobilized cells");
%             phytase = FermentationProcessDescription("Phytase", "Phytase", "Phytase");
            
            this.listOfFermetationProcesses = [emptyFP ecoliFB glucoicAcid];
        end
        
        function this = initializeListOfOptimizationProcess(this)
            
            emptyAlgorithm = AlgorithmDescription(" -- Select an algorithm -- ", '', []);
            
            ea = AlgorithmDescription.createEvolutionaryAlgorithmDescription();
            ga = AlgorithmDescription.createGeneticAlgorithmDescription();
            eaga = AlgorithmDescription.createEAGAHybridDescription();
            
            this.listOfOptimizationAlgorithms = [emptyAlgorithm ea ga eaga];
        end
    end
    
end

