classdef EquationsList
    % EquationsList describes the list of equations in a model
    %   Characteristics:
    %       elements (list of equation descriptions)
    
    properties
        elements;
    end
    
    methods
        %% constructor
        % creates an empty list of equations
        function this = EquationsList()
            this.elements = EquationDescription.empty;
        end
        
        %% adds an equation to the current list of equations
        function this = addEquation(this, equation)
            this.elements(end + 1) = equation;
        end
        
        %% returns the elements at position index
        % checks for a valid position
        function element = getElementAt(this, index)
            if index <= 0 || index > length(this.elements)
                 exception = MException('ArrayIndex:OutOfBounds', 'EquationList: Index out of bound!');
                 throw(exception);
            end
            
            element = this.elements(index);
        end
        
        %% checks if the current equation list is empty
        function empty = isEmpty(this)
            empty = isempty(this.elements);
        end
    end
    
end

